#!/bin/sh
PYTHONPATH=/usr/share/liveusb-creator-ubuntu:/usr/lib/liveusb-creator-ubuntu
export PYTHONPATH
LIVEUSBCREATOR=$0
export LIVEUSBCREATOR
exec gksudo -- python /usr/share/liveusb-creator-ubuntu/liveusb-creator ${1+"$@"}
